@@ -1,24 +1,28 @@
-# $Id: amazon.rb,v 1.52 2004/09/24 02:50:44 ianmacd Exp $
+# $Id: amazon.rb,v 1.54 2005/03/02 03:36:42 ianmacd Exp $
 # 
 #:include: ../README.rdoc
 
 module Amazon
 
   NAME	      = 'Ruby/Amazon'
-  VERSION     = '0.8.5'
+  VERSION     = '0.9.0'
   USER_AGENT  = "%s %s" % [NAME, VERSION]
 
-  SITE	      = { 'us' => 'www.amazon.com',
-		  'uk' => 'www.amazon.co.uk',
+  SITE	      = { 'ca' => 'www.amazon.ca',
 		  'de' => 'www.amazon.de',
-		  'jp' => 'www.amazon.co.jp'
+		  'fr' => 'www.amazon.fr',
+		  'jp' => 'www.amazon.co.jp',
+		  'uk' => 'www.amazon.co.uk',
+		  'us' => 'www.amazon.com'
   }
 
   # :stopdoc:
-  DEFAULT_ID  = { 'us' => 'calibanorg-20',
-		  'uk' => 'caliban-21',
+  DEFAULT_ID  = { 'ca' => 'caliban-20',
 		  'de' => 'calibanorg0a-21',
-		  'jp' => 'calibanorg-20'
+		  'fr' => 'caliban08-21',
+		  'jp' => 'calibanorg-20',
+		  'uk' => 'caliban-21',
+		  'us' => 'calibanorg-20'
   }
   # :startdoc:
 
