@@ -1,4 +1,4 @@
-# $Id: locale.rb,v 1.3 2004/09/21 17:30:37 ianmacd Exp $
+# $Id: locale.rb,v 1.4 2005/03/02 02:55:46 ianmacd Exp $
 #
 
 catch :done do
@@ -25,29 +25,39 @@ catch :done do
       # These constant lists are obviously not complete.
 
       # ISO 3166[http://www.iso.ch/iso/en/prods-services/iso3166ma/02iso-3166-code-lists/iso_3166-1_decoding_table.html]
-      # codes of countries likely to want to shop in the DE locale.
+      # codes of countries likely to want to shop in the CA locale.
+      #
+      CA = %w[ ca ]
+
+      # ISO 3166 codes of countries likely to want to shop in the DE locale.
       #
       DE = %w[ at ch de ]
 
+      # ISO 3166 codes of countries likely to want to shop in the FR locale.
+      #
+      FR = %w[ fr ]
+
       # ISO 3166 codes of countries likely to want to shop in the JP locale.
       #
       JP = %w[ jp ]
 
       # ISO 3166 codes of countries likely to want to shop in the UK locale.
       #
-      UK = %w[ ad al ba be cy cz dk ee es fi fo fr gi gr gl ie is it li lt
-	       lu lv mk mt nl no pl pt ro se si sk sm uk ]
+      UK = %w[ ad al ba be cy cz dk ee es fi fo gi gr gl ie is it li lt lu
+	       lv mk mt nl no pl pt ro se si sk sm uk ]
 
       # ISO 3166 codes of countries likely to want to shop in the US locale.
       # Any countries not explicitly listed above default to the US locale. 
       #
-      US = %w[ ca mx us ]
+      US = %w[ mx us ]
 
 
       def Locale.localise(code)
 	code.downcase!
 
+	return 'ca' if CA.include? code
 	return 'de' if DE.include? code
+	return 'fr' if FR.include? code
 	return 'jp' if JP.include? code
 	return 'uk' if UK.include? code
 
@@ -56,8 +66,8 @@ catch :done do
       private_class_method :localise
 
 
-      # This will attempt to return a reasonable locale (*de*, *jp*, *uk* or
-      # *us*) to use for _host_.
+      # This will attempt to return a reasonable locale (*ca*, *de*, *fr*,
+      # *jp*, *uk* or *us*) to use for _host_.
       #
       # For example:
       #
@@ -67,8 +77,8 @@ catch :done do
 	localise(Net::GeoIP.new.country_code_by_name(host))
       end
 
-      # This will attempt to return a reasonable locale (*de*, *jp*, *uk* or
-      # *us*) to use for the IP address _addr_.
+      # This will attempt to return a reasonable locale (*ca*, *de*, *fr*,
+      # *jp*, *uk* or *us*) to use for the IP address _addr_.
       #
       # For example:
       #
