@@ -1,4 +1,4 @@
-# $Id: search.rb,v 1.129 2004/09/22 09:58:29 ianmacd Exp $
+# $Id: search.rb,v 1.132 2005/03/02 08:12:39 ianmacd Exp $
 #
 
 require 'amazon'
@@ -68,10 +68,12 @@ module Amazon
 
     # The server to contact for the various Amazon locales.
     #
-    LOCALES = { 'us' => 'xml.amazon.com',
-		'uk' => 'xml-eu.amazon.com',
+    LOCALES = { 'ca' => 'xml.amazon.ca',
 		'de' => 'xml-eu.amazon.com',
-		'jp' => 'xml.amazon.co.jp'
+		'fr' => 'xml.amazon.fr',
+		'jp' => 'xml.amazon.co.jp',
+		'uk' => 'xml-eu.amazon.com',
+		'us' => 'xml.amazon.com',
     }
 
     # The mode to use for each category of product in the various Amazon
@@ -79,76 +81,114 @@ module Amazon
     #
     MODES = { 'books'	      => { 'uk' => 'books-uk',
 				   'de' => 'books-de',
-				   'jp' => 'books-jp'
+				   'jp' => 'books-jp',
+				   'fr' => 'books-fr',
+				   'ca' => 'books-ca'
 				 },
 	      'music'	      => { 'uk' => 'music',
 				   'de' => 'pop-music-de',
-				   'jp' => 'music-jp'
+				   'jp' => 'music-jp',
+				   'fr' => 'music-fr',
+				   'ca' => 'music-ca'
 				 },
 	      'classical'     => { 'uk' => 'classical',
 				   'de' => 'classical-de',
-				   'jp' => 'classical-jp'
+				   'jp' => 'classical-jp',
+				   'fr' => 'classical-fr',
+				   'ca' => 'classical-ca'
 				 },
 	      'dvd'	      => { 'uk' => 'dvd-uk',
 				   'de' => 'dvd-de',
-				   'jp' => 'dvd-jp'
+				   'jp' => 'dvd-jp',
+				   'fr' => 'dvd-fr',
+				   'ca' => 'dvd-ca'
 				 },
 	      'vhs'	      => { 'uk' => 'vhs-uk',
 				   'de' => 'vhs-de',
-				   'jp' => 'vhs-jp'
+				   'jp' => 'vhs-jp',
+				   'fr' => 'vhs-fr',
+				   'ca' => 'vhs-ca'
 				 },
 	      'video'	      => { 'uk' => 'video',
 				   'de' => 'video',
-				   'jp' => 'video-jp'
+				   'jp' => 'video-jp',
+				   'fr' => nil,
+				   'ca' => 'video'
 				 },
 	      'electronics'   => { 'uk' => 'electronics',
 				   'de' => 'ce-de',
-				   'jp' => 'electronics-jp'
+				   'jp' => 'electronics-jp',
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'kitchen'	      => { 'uk' => 'kitchen-uk',
 				   'de' => 'kitchen-de',
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'software'      => { 'uk' => 'software-uk',
 				   'de' => 'software-de',
-				   'jp' => 'software-jp'
+				   'jp' => 'software-jp',
+				   'fr' => 'software-fr',
+				   'ca' => 'software-ca'
 				 },
 	      'videogames'    => { 'uk' => 'video-games-uk',
 				   'de' => 'video-games-de',
-				   'jp' => 'videogames-jp'
+				   'jp' => 'videogames-jp',
+				   'fr' => 'video-games-fr',
+				   'ca' => 'video-games-ca'
 				 },
 	      'magazines'     => { 'uk' => nil,
 				   'de' => 'magazines-de',
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'toys'	      => { 'uk' => 'toys-uk',
 				   'de' => nil,
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'photo'	      => { 'uk' => nil,
 				   'de' => 'photo-de',
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'baby'	      => { 'uk' => nil,
 				   'de' => nil,
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'garden'	      => { 'uk' => nil,
 				   'de' => 'garden-de',
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'pc-hardware'   => { 'uk' => nil,
 				   'de' => 'pc-de',
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'tools'	      => { 'uk' => nil,
 				   'de' => 'tools-de',
-				   'jp' => nil
+				   'jp' => nil,
+				   'fr' => nil,
+				   'ca' => nil
 				 },
 	      'english-books' => { 'uk' => nil,
 				   'de' => 'books-de-intl-us',
-				   'jp' => 'books-us'
+				   'jp' => 'books-us',
+				   'fr' => 'books-fr-intl-us',
+				   'ca' => 'books-ca-en'
 				 }
+	      # ca has the additional category, 'books-ca-fr', for French
+	      # language books.
     }
 
     # The sort types available to each product mode.
@@ -288,10 +328,10 @@ module Amazon
       # _associate_ is your
       # Associates[https://associates.amazon.com/exec/panama/associates/apply/]
       # ID, _locale_ is the search locale in which you wish to work (*us*,
-      # *uk*, *de* or *jp*), _cache_ is whether or not to utilise a response
-      # cache, and _user_agent_ is the name of the client you wish to pass
-      # when performing calls to AWS. _locale_ and _cache_ can also be set
-      # later, if you wish to change the current behaviour.
+      # *uk*, *de*, *fr*, *ca* or *jp*), _cache_ is whether or not to utilise
+      # a response cache, and _user_agent_ is the name of the client you wish
+      # to pass when performing calls to AWS. _locale_ and _cache_ can also be
+      # set later, if you wish to change the current behaviour.
       #
       # For example:
       #
@@ -510,7 +550,7 @@ module Amazon
 	mode = localise_mode(mode)
 	url = url % [@id, actor, mode, @type, @token, page] << sort_string
 
-	search(url % [@id, actor, mode, @type, @token, page], &block)
+	search(url, &block)
       end
 
 
@@ -625,7 +665,7 @@ module Amazon
 	mode = localise_mode(mode)
 	url = url % [@id, director, mode, @type, @token, page] << sort_string
 
-	search(url % [@id, director, mode, @type, @token, page], &block)
+	search(url, &block)
       end
 
 
@@ -702,7 +742,7 @@ module Amazon
 	mode = localise_mode(mode)
 	url = url % [@id, director, mode, @type, @token, page] << sort_string
 
-	search(url % [@id, director, mode, @type, @token, page], &block)
+	search(url, &block)
       end
 
 
@@ -820,7 +860,7 @@ module Amazon
 	url =
 	  url % [@id, text_stream, mode, @type, @token, page] << sort_string
 
-	search(url % [@id, text_stream, mode, @type, @token, page], &block)
+	search(url, &block)
       end
 
 
